@@ -11,15 +11,14 @@ logger = logging.getLogger(__name__)
 
 
 class CombinatorialPromptGenerator(PromptGenerator):
-    def __init__(self, wildcard_manager: WildcardManager, template):
+    def __init__(self, wildcard_manager: WildcardManager):
         self._wildcard_manager = wildcard_manager
-        self._template = template
         self._generator = CombinatorialGenerator(wildcard_manager)
 
-    def generate(self, max_prompts=constants.MAX_IMAGES) -> list[str]:
-        if self._template is None or len(self._template) == 0:
+    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> list[str]:
+        if template is None or len(template) == 0:
             return [""]
-        prompts = self._generator.generate_prompts(self._template, max_prompts)
+        prompts = self._generator.generate_prompts(template, max_prompts)
         prompts = list(prompts)
 
         return prompts
